@@ -14,17 +14,28 @@ our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
   blessed refaddr reftype weaken unweaken isweak
 
-  isbool
-
   dualvar isdual isvstring looks_like_number openhandle readonly set_prototype
   tainted
 );
-our $VERSION    = "1.58";
+our $VERSION    = "1.64";
 $VERSION =~ tr/_//d;
 
 require List::Util; # List::Util loads the XS
 List::Util->VERSION( $VERSION ); # Ensure we got the right XS version (RT#100863)
 
+if( $] >= 5.040 ) {
+  # On Perl 5.40 and above, these builtins are stable, so we can use them
+  # instead of our own XS implementation
+
+  # Using this instead of a globref means we don't create an empty
+  # "builtins::" glob on older perls
+  no strict 'refs';
+  my $builtins = \%{"builtin::"};
+
+  *$_ = \&{ $builtins->{$_} } for (qw( blessed refaddr reftype weaken unweaken ));
+  *isweak = \&{ $builtins->{is_weak} };  # renamed
+}
+
 # populating @EXPORT_FAIL is done in the XS code
 sub export_fail {
   if (grep { /^isvstring$/ } @_ ) {
@@ -32,11 +43,6 @@ sub export_fail {
     Carp::croak("Vstrings are not implemented in this version of perl");
   }
 
-  if (grep { /^isbool$/ } @_ ) {
-    require Carp;
-    Carp::croak("isbool is not implemented in this version of perl");
-  }
-
   @_;
 }
 
@@ -71,6 +77,21 @@ being individual extensions would be wasteful.
 
 By default C<Scalar::Util> does not export any subroutines.
 
+=head2 Core Perl C<builtin> Functions
+
+Many functions in this module have served as the inspiration for a new
+experimental facility in recent versions of Perl. From various development
+versions, starting at 5.35.7, equivalent functions to many of these utilities
+are available in the C<builtin::> package.
+
+    use Scalar::Util qw(blessed);
+
+    $class = blessed $obj;
+
+    $class = builtin::blessed $obj;  # equivalent
+
+For more information, see the documentation on L<builtin>.
+
 =cut
 
 =head1 FUNCTIONS FOR REFERENCES
@@ -96,6 +117,9 @@ into is returned. Otherwise C<undef> is returned.
 Take care when using this function simply as a truth test (such as in
 C<if(blessed $ref)...>) because the package name C<"0"> is defined yet false.
 
+I<Since Perl version 5.35.7> an equivalent function is available as
+C<builtin::blessed>.
+
 =head2 refaddr
 
     my $addr = refaddr( $ref );
@@ -110,6 +134,9 @@ returned as a plain integer. Otherwise C<undef> is returned.
     $obj  = bless {}, "Foo";
     $addr = refaddr $obj;               # eg 88123488
 
+I<Since Perl version 5.35.7> an equivalent function is available as
+C<builtin::refaddr>.
+
 =head2 reftype
 
     my $type = reftype( $ref );
@@ -130,6 +157,9 @@ blessed references; thus C<ref()> returns the package name string C<"Regexp">
 on these but C<reftype()> will return the underlying C structure type of
 C<"REGEXP"> in all capitals.
 
+I<Since Perl version 5.35.7> an equivalent function is available as
+C<builtin::reftype>.
+
 =head2 weaken
 
     weaken( $ref );
@@ -169,6 +199,9 @@ references to objects will be strong, causing the remaining objects to never be
 destroyed because there is now always a strong reference to them in the @object
 array.
 
+I<Since Perl version 5.35.7> an equivalent function is available as
+C<builtin::weaken>.
+
 =head2 unweaken
 
     unweaken( $ref );
@@ -190,6 +223,9 @@ otherwise-equivalent code
 (because in particular, simply assigning a weak reference back to itself does
 not work to unweaken it; C<$REF = $REF> does not work).
 
+I<Since Perl version 5.35.7> an equivalent function is available as
+C<builtin::unweaken>.
+
 =head2 isweak
 
     my $weak = isweak( $ref );
@@ -206,18 +242,11 @@ B<NOTE>: Copying a weak reference creates a normal, strong, reference.
     $copy = $ref;
     $weak = isweak($copy);              # false
 
+I<Since Perl version 5.35.7> an equivalent function is available as
+C<builtin::is_weak>.
+
 =head1 OTHER FUNCTIONS
 
-=head2 isbool
-
-    my $bool = isbool( $var );
-
-I<Available only since perl 5.35.3 onwards.>
-
-Returns true if the given variable is boolean in nature - that is, it is the
-result of a boolean operator (such as C<defined>, C<exists>, or a numerical or
-string comparison), or is a variable that is copied from one.
-
 =head2 dualvar
 
     my $var = dualvar( $num, $string );
@@ -330,11 +359,6 @@ Module use may give one of the following errors during import.
 The version of perl that you are using does not implement Vstrings, to use
 L</isvstring> you will need to use a newer release of perl.
 
-=item isbool is not implemented in this version of perl
-
-The version of perl that you are using does not implement stable boolean
-tracking, to use L</isbool> you will need to use a newer release of perl.
-
 =back
 
 =head1 KNOWN BUGS
